Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(918)

Unified Diff: ppapi/nacl_irt/plugin_startup.h

Issue 2148633002: Pass around IPC::ChannelHandles instead of raw fds in the NaCl IRT. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/nacl_irt/plugin_startup.h
diff --git a/ppapi/nacl_irt/plugin_startup.h b/ppapi/nacl_irt/plugin_startup.h
index 2684a78316bc821e670bb6d2f9d926b17b1efb1f..6885c2f801be635d5d22f0978ddd2eb244fccc9d 100644
--- a/ppapi/nacl_irt/plugin_startup.h
+++ b/ppapi/nacl_irt/plugin_startup.h
@@ -5,6 +5,7 @@
#ifndef PPAPI_NACL_IRT_PLUGIN_STARTUP_H_
#define PPAPI_NACL_IRT_PLUGIN_STARTUP_H_
+#include "ipc/ipc_channel_handle.h"
#include "ppapi/proxy/ppapi_proxy_export.h"
namespace base {
@@ -19,19 +20,21 @@ class ManifestService;
// Sets the IPC channels for the browser and the renderer by the given FD
Mark Seaborn 2016/07/13 19:23:10 Update "FD numbers" in comment?
Anand Mistry (off Chromium) 2016/07/13 23:49:42 Done.
// numbers. This will be used for non-SFI mode. Must be called before the
// ppapi_start() IRT interface is called.
-PPAPI_PROXY_EXPORT void SetIPCFileDescriptors(
- int browser_ipc_fd, int renderer_ipc_fd, int manifest_service_fd);
+PPAPI_PROXY_EXPORT void SetIPCChannelHandles(
+ IPC::ChannelHandle browser_ipc_fd,
Mark Seaborn 2016/07/13 19:23:10 "fd" -> "handle"
Anand Mistry (off Chromium) 2016/07/13 23:49:42 Done.
+ IPC::ChannelHandle renderer_ipc_fd,
+ IPC::ChannelHandle manifest_service_fd);
// Runs start up procedure for the plugin.
// Specifically, start background IO thread for IPC, and prepare
// shutdown event instance.
PPAPI_PROXY_EXPORT void StartUpPlugin();
-// Returns IPC file descriptor for PPAPI to the browser.
-int GetBrowserIPCFileDescriptor();
+// Returns IPC channel handle for PPAPI to the browser.
+IPC::ChannelHandle GetBrowserIPCChannelHandle();
-// Returns IPC file descriptor for PPAPI to the renderer.
-int GetRendererIPCFileDescriptor();
+// Returns IPC channel handle for PPAPI to the renderer.
+IPC::ChannelHandle GetRendererIPCChannelHandle();
// Returns the shutdown event instance for the plugin.
// Must be called after StartUpPlugin().

Powered by Google App Engine
This is Rietveld 408576698